@@ -26,7 +26,7 @@ from refine_contigs.utils import (
 )
 import gzip
 import networkx as nx
-import pathlib, os
+import pathlib, os, sys
 from Bio import SeqIO
 import uuid
 import pandas as pd
@@ -34,13 +34,14 @@ import pyfaidx
 
 log = logging.getLogger("my_logger")
 
+sys.setrecursionlimit(10**6)
 
 def split_contigs(args):
 
     prefix = args.prefix
     dname = str(uuid.uuid4())
     tmp_dir = pathlib.Path(args.tmp_dir, dname).absolute()
-
+    min_id = float(100.0 * args.min_id)
     if not os.path.isdir(tmp_dir):
         os.makedirs(tmp_dir, exist_ok=True)
 
@@ -69,7 +70,7 @@ def split_contigs(args):
         tmp_dir=tmp_dir,
         max_seq_len=max_seq_len,
         threads=args.threads,
-        min_id=args.min_id,
+        min_id=min_id,
         min_cov=args.min_cov,
     )
 
@@ -96,7 +97,7 @@ def split_contigs(args):
         parms = {
             "contigs": str(contigs_tmp),
             "results": results,
-            "min_id": args.min_id,
+            "min_id": min_id,
             "min_cov": args.min_cov,
             "contigs_len": contigs_len,
             "threads": args.threads,
@@ -122,7 +123,7 @@ def split_contigs(args):
             f"Found {miss_contigs_ovl} overlaps in {len(miss_contigs)} contigs ({miss_contigs_ovl_nt_prop:.2f}% of the assembly)"
         )
 
-        aln_reg_fname = f"{args.output}.splits.overlaps.tsv.gz"
+        aln_reg_fname = f"{args.output}.split.overlaps.tsv.gz"
         logging.info(f"Saving overlaps to {aln_reg_fname}")
 
         contigs_names = contigs[["name", "name_original"]]
