@@ -97,24 +97,22 @@ def is_valid_file(parser, arg, var):
 defaults = {
     "tmp": "./tmp",
     "threads": 2,
-    "min_id": 95.0,
+    "min_id": 0.9,
     "min_cov": 0.25,
     "output": "contigs",
     "prefix": "contig",
-    "frag_min_len": 1000,
-    "frag_cls_id": 0.95,
+    "frag_min_len": 500,
+    "frag_cls_id": 0.9,
     "frag_cls_cov": 0.6,
-    "global_cls_id": 0.9,
+    "global_cls_id": 0.99,
     "global_cls_cov": 0.9,
     "minimus2_threads": 1,
     "minimus2_overlap": 500,
     "minimus2_minid": 95.0,
-    "minimus2_maxtrim": 100,
+    "minimus2_maxtrim": 1000,
     "minimus2_conserr": 0.06
 }
 
-
-
 help_msg = {
     "search_results": f"MMseqs2 search results",
     "contigs": f"Contig file to check for misassemblies",
@@ -218,7 +216,7 @@ def get_arguments(argv=None):
         "--min-id",
         metavar="FLOAT",
         type=lambda x: check_values(
-            x, minval=0, maxval=100, parser=parser, var="--min-id"
+            x, minval=0, maxval=1, parser=parser, var="--min-id"
         ),
         dest="min_id",
         default=defaults["min_id"],
@@ -260,7 +258,7 @@ def get_arguments(argv=None):
     )
 
     parser_merge = sub_parsers.add_parser(
-        "merge", help="Find misassemblies", parents=[parent_parser]
+        "merge", help="Merge potential overlaps", parents=[parent_parser]
     )
 
     frag_args = parser_split.add_argument_group("fragment refinement arguments")
@@ -320,7 +318,7 @@ def get_arguments(argv=None):
         "--mnm2-minid",
         metavar="FLOAT",
         type=lambda x: check_values(
-            x, minval=0, maxval=100, parser=parser, var="--min-id"
+            x, minval=0, maxval=100, parser=parser, var="--mnm2-minid"
         ),
         dest="minimus2_minid",
         default=defaults["minimus2_minid"],
@@ -338,7 +336,7 @@ def get_arguments(argv=None):
         "--mnm2-conserr",
         metavar="FLOAT",
         type=lambda x: check_values(
-            x, minval=0, maxval=1, parser=parser, var="--min-cov"
+            x, minval=0, maxval=1, parser=parser, var="--mnm2-conserr"
         ),
         default=defaults["minimus2_conserr"],
         help=help_msg["minimus2_conserr"],
@@ -381,9 +379,10 @@ def create_graph(results, min_id, min_cov):
     G = nx.Graph().to_undirected()
     M = nx.from_pandas_edgelist(
         results_filt,
-        edge_attr=["weight"],
+        edge_attr=["weight", "pident"],
         create_using=nx.MultiGraph(),
     )
+
     for u, v, data in M.edges(data=True):
         if not G.has_edge(u, v):
             # set weight to 1 if no weight is given for edge in M
